#
# spec file for package python-branca
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
# no ipython
%global skip_python39 1
Name:           python-branca
Version:        0.8.1
Release:        1.2
Summary:        HTML+JS page generator
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/python-visualization/branca
# Only the Github archive has the tests. Requires manually setting the version for setuptools_scm below
Source:         https://github.com/python-visualization/branca/archive/v%{version}.tar.gz#/branca-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 41.2}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module nbconvert}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module selenium}
# /SECTION
%python_subpackages

%description
Generate HTML+JS pages with Python.

%prep
%autosetup -p1 -n branca-%{version}

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_rendering_utf8_iframe and test_rendering_figure_notebook require geckodriver
%pytest -k 'not (test_rendering_utf8_iframe or test_rendering_figure_notebook)'

%files %{python_files}
%doc CHANGES.txt README.md
%license LICENSE.txt
%{python_sitelib}/branca
%{python_sitelib}/branca-%{version}.dist-info

%changelog
* Mon Jan  6 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.8.1
  * Add py.typed file
* Thu Sep  5 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * ColorMap text color
  * Add type hints
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.2:
  * Remove `split_six` utility function
  * COMPAT: explictly cast numpy floats to native floats
  * Remove empty plugins folder
  * Drop Py3.7, add Py3.12
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  * Remove _env instance attribute from Element
  * Add jinja2 version constraint
* Wed Mar 13 2024 Dirk Müller <dmueller@suse.com>
- skip build on python 3.9 due to missing ipython
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 0.7.0:
  * Make all Element with Template pickable natively
  * Make _parse_size robust to already parsed values
  * StepColormap: inclusive lower bound
  * Add color schemes: plasma, inferno, magma
  * Allow branca ColorMap in write_png
  * More flexible _parse_size
* Wed Dec 21 2022 Ben Greiner <code@bnavigator.de>
- Fix build requirements and version metadata
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.6.0
  - Properly escape colormap caption (@Conengmo #117)
  - Multiple fixes in color_brewer (@ajabep #115)
  - Expose colorbar size variables (@Conengmo #77)
  - Proper html tags in Figure template (@desrod #67)
  - Make Element class pickleable (@bwest2397 #99)
  - Improve colorbar representation in notebooks (@HaudinFlorence #110)
  - Allow custom ticks on colorbar (@kota7 #113)
* Fri Sep 23 2022 pgajdos@suse.com
- python-six is not required
* Fri Sep 23 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.5.0:
  * Support for Pathlib when saving an `Element` (@wd60622 #103)
  * Faster UUID generation for `Element` id (@bwest2397 #101)
  * Store html content in `srcdoc` instead of `data-html` (@dstein64 #96)
  * Add `max_labels` argument to color maps (@martinfleis #90)
  * Pass caption when converting colormap to steps (@ndswaef #87)
- Update to version 0.4.2
  * Fix special char encoding in notebooks, store as percent-encoded (@conengmo #76)
* Tue Jun 28 2022 Daniel García Moreno <dani@danigm.net>
- New BuildRequires for tests: ipykernel
* Sun Jan 10 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.4.2:
  * Fix special char encoding in notebooks, store as
    percent-encoded (gh#python-visualization/branca#76).
- New BuildRequires for tests: python-nbconvert.
- Disable an additional test that also requires 'geckodriver'.
- Use source name in the format branca-%%{version}.
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 0.4.0
  - Dropped Python 2 support
  - Store html content in a data-html attribute (#66)
  - Colormap alpha #64
  - Fix caption being propagated in scale functions #62
  - Assert color type in color_brewer #52
* Thu Jun  6 2019 pgajdos@suse.com
- run the testsuite
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
